@@ -78,10 +78,13 @@ class PREFS(object):
 
         self.ReadPrefs()
 
-    def ReWritePrefs(self, prefs = self.prefs):
+    def ReWritePrefs(self, prefs = 0):
         if os.path.exists(f"{self.filename}.txt"):
             os.remove(f"{self.filename}.txt")
-            self.CreatePrefs(prefs)
+            try:
+                self.CreatePrefs(prefs)
+            except AttributeError:
+                self.CreatePrefs(self.prefs)                
 
         self.ReadPrefs()
             
